@@ -79,6 +79,6 @@ ode23 <- function(f, t0, tfinal, y0, ..., rtol = 1e-3, atol = 1e-6) {
     } # end while
 
     # Return results
-    return(list(t = as.matrix(tout), y = yout))
+    return(list(t = c(tout), y = yout))
 }
 
